@@ -11,6 +11,7 @@ class WialonUnit(WialonBase):
     """A Wialon `unit <https://help.wialon.com/en/wialon-hosting/user-guide/management-system/units>`_."""
 
     def __init__(self, *args, **kwargs) -> None:
+        """Sets :py:attr:`_imei_number`, :py:attr:`_active` and :py:attr:`_image_uri` to :py:obj:`None`."""
         super().__init__(*args, **kwargs)
         self._imei_number = None
         self._active = None
@@ -83,32 +84,50 @@ class WialonUnit(WialonBase):
 
         Response format:
 
-        +----------+--------------------+-----------------+
-        | key      | type               | desc            |
-        +==========+====================+=================+
-        | ``"t"``  | :py:obj:`datetime` | Time (UTC)      |
-        +----------+--------------------+-----------------+
-        | ``"y"``  | :py:obj:`float`    | Latitude        |
-        +----------+--------------------+-----------------+
-        | ``"x"``  | :py:obj:`float`    | Longitude       |
-        +----------+--------------------+-----------------+
-        | ``"z"``  | :py:obj:`float`    | Altitude        |
-        +----------+--------------------+-----------------+
-        | ``"s"``  | :py:obj:`int`      | Speed           |
-        +----------+--------------------+-----------------+
-        | ``"c"``  | :py:obj:`int`      | Course          |
-        +----------+--------------------+-----------------+
-        | ``"sc"`` | :py:obj:`int`      | # of satellites |
-        +----------+--------------------+-----------------+
+        +----------+------------------------------+-----------------+
+        | key      | type                         | desc            |
+        +==========+==============================+=================+
+        | ``"t"``  | :py:obj:`~datetime.datetime` | Time (UTC)      |
+        +----------+------------------------------+-----------------+
+        | ``"y"``  | :py:obj:`float`              | Latitude        |
+        +----------+------------------------------+-----------------+
+        | ``"x"``  | :py:obj:`float`              | Longitude       |
+        +----------+------------------------------+-----------------+
+        | ``"z"``  | :py:obj:`float`              | Altitude        |
+        +----------+------------------------------+-----------------+
+        | ``"s"``  | :py:obj:`int`                | Speed           |
+        +----------+------------------------------+-----------------+
+        | ``"c"``  | :py:obj:`int`                | Course          |
+        +----------+------------------------------+-----------------+
+        | ``"sc"`` | :py:obj:`int`                | # of satellites |
+        +----------+------------------------------+-----------------+
 
         """
-        response = self.session.wialon_api.core_search_item(
-            **{"id": self.id, "flags": flags.DataFlag.UNIT_POSITION}
-        ).get("pos", {})
+        response = (
+            self.session.wialon_api.core_search_item(
+                **{"id": self.id, "flags": flags.DataFlag.UNIT_POSITION}
+            )
+            .get("item", {})
+            .get("pos", {})
+        )
         if response:
             response["t"] = datetime.fromtimestamp(response["t"])
         return response
 
+    def get_command_messages(
+        self, start_time: datetime, total: int = 1, count: int = 1
+    ) -> list[dict[str, str]]:
+        return self.session.wialon_api.messages_load_last(
+            **{
+                "itemId": self.id,
+                "lastTime": int(start_time.timestamp()),
+                "flags": 0x0200,
+                "flagsMask": 0,
+                "lastCount": total,
+                "loadCount": count,
+            }
+        )
+
     def execute_command(
         self,
         name: str,
@@ -256,9 +275,11 @@ class WialonUnit(WialonBase):
         :rtype: :py:obj:`list`
 
         """
+        print("Getting driver phone numbers...")
         response = self.session.wialon_api.resource_get_unit_drivers(
             **{"unitId": self.id}
         )
+        print(f"{response = }")
         if response:
             dirty_phones = [driver[0].get("ph") for driver in response.values()]
             return self.clean_phone_numbers(dirty_phones)
@@ -281,8 +302,12 @@ class WialonUnit(WialonBase):
         :type: :py:obj:`dict`
 
         """
-        return self.session.wialon_api.core_get_hw_cmds(
-            **{"deviceTypeId": 0, "unitId": self.id}
+        return (
+            self.session.wialon_api.core_search_item(
+                **{"id": self.id, "flags": flags.DataFlag.UNIT_AVAILABLE_COMMANDS}
+            )
+            .get("item", {})
+            .get("cml", {})
         )
 
     @property
